@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe Faraday::Adapter::EMSynchrony do
+RSpec.describe Faraday::Adapter::EMSynchrony, unless: defined?(JRUBY_VERSION) do
   features :request_body_on_query_methods, :reason_phrase_parse,
            :skip_response_body_on_head, :parallel, :local_socket_binding
 
